@@ -59,6 +59,16 @@ impl Compiler<'_> {
             // Later, in the compile function, the while loop is converted to two databind
             // functions.
             if building_while {
+                if current_keyword.trim() == ":endwhile" {
+                    building_while = false;
+                    building_keyword = false;
+                    current_keyword = String::new();
+                    tokens.push(Token::WhileContents(while_lines.join("\n")));
+                    while_line = String::new();
+                    while_lines = Vec::new();
+                    tokens.push(Token::EndWhileLoop);
+                }
+
                 if building_condition {
                     if self.current_char == '\n' {
                         tokens.push(Token::WhileCondition(current_keyword.trim().to_string()));
@@ -73,14 +83,6 @@ impl Compiler<'_> {
                         while_line = String::new();
                     }
                 }
-
-                if current_keyword.trim() == ":endwhile" {
-                    building_while = false;
-                    tokens.push(Token::WhileContents(while_lines.join("\n")));
-                    while_line = String::new();
-                    while_lines = Vec::new();
-                    tokens.push(Token::EndWhileLoop);
-                }
             }
 
             if !building_keyword && last_char.is_whitespace() && self.current_char == ':' {
@@ -138,10 +140,6 @@ impl Compiler<'_> {
                         building_while = true;
                         building_condition = true;
                     }
-                    "endwhile" => {
-                        tokens.push(Token::EndWhileLoop);
-                        building_keyword = false;
-                    }
                     _ => keyword_found = false,
                 }
 
@@ -351,6 +349,7 @@ impl Compiler<'_> {
             } else if self.current_char == '#'
                 && tokens.last().ok_or(Token::None).is_ok()
                 && tokens.last().unwrap() == &Token::NewLine
+                && current_non_databind.is_empty()
             {
                 comment = true;
                 continue;
