@@ -76,7 +76,9 @@ fn get_subfolder_prefix<P: AsRef<Path>>(functions_path: &P) -> String {
     // Ensure no backslashes and remove leading slash, if present
     let prefix = after_functions.to_str().unwrap().replace('\\', "/");
 
-    if let Some(new) = prefix.strip_prefix('/') {
+    if prefix == "/" {
+        String::new()
+    } else if let Some(new) = prefix.strip_prefix('/') {
         format!("{}/", new)
     } else {
         format!("{}/", prefix)
@@ -138,7 +140,7 @@ fn main() -> std::io::Result<()> {
         if let Ok(config) = config_location {
             // Get base directory of project from config file location
             let base_dir = config.parent().unwrap();
-            args.push(format!("{}/src", base_dir.display()));
+            args.push(base_dir.to_str().unwrap().into());
             cli::get_app().get_matches_from(args)
         } else {
             // Run with no args to show help menu
